==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieOdplatnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SwiadczenieOdplatnosc extends GenericDPSObject {
    /**
     * SWIADCZENIE_ODPLATNOSC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SWIADCZENIE_ODPLATNOSC.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * SWIADCZENIE_ODPLATNOSC.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * SWIADCZENIE_ODPLATNOSC.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_ODPLATNOSC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_ODPLATNOSC.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @return SWIADCZENIE_ODPLATNOSC.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return SWIADCZENIE_ODPLATNOSC.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieOdplatnosc other = (SwiadczenieOdplatnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append(", data=").append(data);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieOdplatnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SwiadczenieOdplatnosc extends GenericDPSObject {
    /**
     * SWIADCZENIE_ODPLATNOSC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SWIADCZENIE_ODPLATNOSC.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * SWIADCZENIE_ODPLATNOSC.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * SWIADCZENIE_ODPLATNOSC.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_ODPLATNOSC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_ODPLATNOSC.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @return SWIADCZENIE_ODPLATNOSC.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return SWIADCZENIE_ODPLATNOSC.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * SWIADCZENIE_ODPLATNOSC.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieOdplatnosc other = (SwiadczenieOdplatnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append(", data=").append(data);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}
